@@ -36,27 +36,27 @@
 
 #include "gedit-style-scheme-manager.h"
 #include "gedit-prefs-manager.h"
+#include "gedit-dirs.h"
 
 static GtkSourceStyleSchemeManager *style_scheme_manager = NULL;
 
-#define GEDIT_STYLES_DIR ".gnome2/gedit/styles"
-
 static gchar *
 get_gedit_styles_path (void)
 {
-	const gchar *home;
+	gchar *config_dir;
+	gchar *dir = NULL;
 
-	home = g_get_home_dir ();
-	if (home != NULL)
+	config_dir = gedit_dirs_get_user_config_dir ();
+
+	if (config_dir != NULL)
 	{
-		gchar *dir;
-
-		dir = g_build_filename (home, GEDIT_STYLES_DIR, NULL);
-
-		return dir;
+		dir = g_build_filename (config_dir,
+					"styles",
+					NULL);
+		g_free (config_dir);
 	}
 	
-	return NULL;
+	return dir;
 }
 
 static void
@@ -131,7 +131,6 @@ _gedit_style_scheme_manager_scheme_is_gedit_user_scheme (GtkSourceStyleSchemeMan
 {
 	GtkSourceStyleScheme *scheme;
 	const gchar *filename;
-	const gchar *home;
 	gchar *dir;
 	gboolean res = FALSE;
 
@@ -143,13 +142,7 @@ _gedit_style_scheme_manager_scheme_is_gedit_user_scheme (GtkSourceStyleSchemeMan
 	if (filename == NULL)
 		return FALSE;
 
-	home = g_get_home_dir ();
-	if (home == NULL)
-		return FALSE;
-
-	dir = g_strdup_printf ("%s/%s",
-			       home,
-			       GEDIT_STYLES_DIR);
+	dir = get_gedit_styles_path ();
 
 	res = g_str_has_prefix (filename, dir);
 
@@ -253,30 +246,48 @@ const gchar *
 _gedit_style_scheme_manager_install_scheme (GtkSourceStyleSchemeManager *manager,
 					    const gchar                 *fname)
 {
-	gchar  *new_file_name;
-	gchar  *basename;
-	gchar  *styles_dir;
+	gchar *new_file_name = NULL;
+	gchar *dirname;
+	gchar *styles_dir;
 	GError *error = NULL;
+	gboolean copied = FALSE;
 
 	const gchar* const *ids;
 
 	g_return_val_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager), NULL);
 	g_return_val_if_fail (fname != NULL, NULL);
 
-	basename = g_path_get_basename (fname);
+	dirname = g_path_get_dirname (fname);
 	styles_dir = get_gedit_styles_path();
-	new_file_name = g_build_filename (styles_dir, basename, NULL);
-	g_free (styles_dir);
-	g_free (basename);
 
-	/* Copy the style scheme file into GEDIT_STYLES_DIR */
-	if (!file_copy (fname, new_file_name, &error))
+	if (strcmp (dirname, styles_dir) != 0)
 	{
-		g_message ("Cannot install style scheme:\n%s",
-			   error->message);
+		gchar *basename;
 
-		return NULL;
+		basename = g_path_get_basename (fname);
+		new_file_name = g_build_filename (styles_dir, basename, NULL);
+		g_free (basename);
+
+		/* Copy the style scheme file into GEDIT_STYLES_DIR */
+		if (!file_copy (fname, new_file_name, &error))
+		{
+			g_free (new_file_name);
+
+			g_message ("Cannot install style scheme:\n%s",
+				   error->message);
+
+			return NULL;
+		}
+
+		copied = TRUE;
 	}
+	else
+	{
+		new_file_name = g_strdup (fname);
+	}
+
+	g_free (dirname);
+	g_free (styles_dir);
 
 	/* Reload the available style schemes */
 	gtk_source_style_scheme_manager_force_rescan (manager);
@@ -305,7 +316,8 @@ _gedit_style_scheme_manager_install_scheme (GtkSourceStyleSchemeManager *manager
 	}
 
 	/* The style scheme has not been correctly installed */
-	g_unlink (new_file_name);
+	if (copied)
+		g_unlink (new_file_name);
 
 	g_free (new_file_name);
 
