@@ -21,7 +21,6 @@ __all__ = ('ExternalToolsPlugin', 'ExternalToolsWindowHelper',
 
 import gedit
 import gtk
-import gnomevfs
 from manager import Manager
 from library import ToolLibrary
 from outputpanel import OutputPanel
@@ -40,64 +39,105 @@ class ToolMenu(object):
 
         self._merge_id = 0
         self._action_group = gtk.ActionGroup("ExternalToolsPluginToolActions")
-        self._window.get_ui_manager().insert_action_group(self._action_group, -1)
+        self._signals = []
+
         self.update()
 
     def deactivate(self):
         self.remove()
-        self._window.get_ui_manager().remove_action_group(self._action_group)
 
     def remove(self):
         if self._merge_id != 0:
             self._window.get_ui_manager().remove_ui(self._merge_id)
+            self._window.get_ui_manager().remove_action_group(self._action_group)
             self._merge_id = 0
 
         for action in self._action_group.list_actions():
             handler = action.get_data(self.ACTION_HANDLER_DATA_KEY)
+
             if handler is not None:
                 action.disconnect(handler)
+
+            action.set_data(self.ACTION_ITEM_DATA_KEY, None)
+            action.set_data(self.ACTION_HANDLER_DATA_KEY, None)
+
             self._action_group.remove_action(action)
+        
+        accelmap = gtk.accel_map_get()
+
+        for s in self._signals:
+            accelmap.disconnect(s)
+        
+        self._signals = []
 
     def _insert_directory(self, directory, path):
         manager = self._window.get_ui_manager()
 
         for item in directory.subdirs:
             action_name = 'ExternalToolDirectory%X' % id(item)
-            action = gtk.Action(action_name, item.name, None, None)
+            action = gtk.Action(action_name, item.name.replace('_', '__'), None, None)
             self._action_group.add_action(action)
 
             manager.add_ui(self._merge_id, path,
                            action_name, action_name,
                            gtk.UI_MANAGER_MENU, False)
+                           
             self._insert_directory(item, path + '/' + action_name)
 
         for item in directory.tools:
             action_name = 'ExternalToolTool%X' % id(item)
-            action = gtk.Action(action_name, item.name, item.comment, None)
+            action = gtk.Action(action_name, item.name.replace('_', '__'), item.comment, None)
             handler = action.connect("activate", capture_menu_action, self._window, item)
 
             action.set_data(self.ACTION_ITEM_DATA_KEY, item)
             action.set_data(self.ACTION_HANDLER_DATA_KEY, handler)
+            
+            # Make sure to replace accel
+            accelpath = '<Actions>/ExternalToolsPluginToolActions/%s' % (action_name, )
+            
+            if item.shortcut:
+                key, mod = gtk.accelerator_parse(item.shortcut)
+                gtk.accel_map_change_entry(accelpath, key, mod, True)
+                
+                self._signals.append(gtk.accel_map_get().connect('changed::%s' % (accelpath,), self.on_accelmap_changed, item))
+                
             self._action_group.add_action_with_accel(action, item.shortcut)
 
             manager.add_ui(self._merge_id, path,
                            action_name, action_name,
                            gtk.UI_MANAGER_MENUITEM, False)
 
+    def on_accelmap_changed(self, accelmap, path, key, mod, tool):
+        tool.shortcut = gtk.accelerator_name(key, mod)
+        tool.save()
+        
+        self._window.get_data("ExternalToolsPluginWindowData").update_manager(tool)
+
     def update(self):
         self.remove()
         self._merge_id = self._window.get_ui_manager().new_merge_id()
         self._insert_directory(self._library.tree, self._menupath)
+        self._window.get_ui_manager().insert_action_group(self._action_group, -1)
         self.filter(self._window.get_active_document())
 
+    def filter_language(self, language, item):
+        if not item.languages:
+            return True
+        
+        if not language and 'plain' in item.languages:
+            return True
+        
+        if language and (language.get_id() in item.languages):
+            return True
+        else:
+            return False
+
     def filter(self, document):
         if document is None:
             return
 
-        uri = document.get_uri()
-
-        titled = uri is not None
-        remote = titled and gnomevfs.get_uri_scheme(uri) != 'file'
+        titled = document.get_uri() is not None
+        remote = not document.is_local()
 
         states = {
             'all' : True,
@@ -106,11 +146,14 @@ class ToolMenu(object):
             'titled': titled,
             'untitled': not titled,
         }
+        
+        language = document.get_language()
 
         for action in self._action_group.list_actions():
             item = action.get_data(self.ACTION_ITEM_DATA_KEY)
+
             if item is not None:
-                action.set_sensitive(states[item.applicability])
+                action.set_visible(states[item.applicability] and self.filter_language(language, item))
 
 class ExternalToolsWindowHelper(object):
     def __init__(self, plugin, window):
@@ -126,10 +169,16 @@ class ExternalToolsWindowHelper(object):
         self._action_group.set_translation_domain('gedit')
         self._action_group.add_actions([('ExternalToolManager',
                                          None,
-                                         _('_External Tools...'),
+                                         _('Manage _External Tools...'),
                                          None,
                                          _("Opens the External Tools Manager"),
-                                         lambda action: plugin.open_dialog())])
+                                         lambda action: plugin.open_dialog()),
+                                        ('ExternalTools',
+                                        None,
+                                        _('External _Tools'),
+                                        None,
+                                        _("External tools"),
+                                        None)])
         manager.insert_action_group(self._action_group, -1)
 
         ui_string = """
@@ -138,7 +187,9 @@ class ExternalToolsWindowHelper(object):
                 <menu name="ToolsMenu" action="Tools">
                   <placeholder name="ToolsOps_4">
                     <separator/>
-                    <placeholder name="ExternalToolPlaceholder"/>
+                    <menu name="ExternalToolsMenu" action="ExternalTools">
+                        <placeholder name="ExternalToolPlaceholder"/>
+                    </menu>
                     <separator/>
                   </placeholder>
                   <placeholder name="ToolsOps_5">
@@ -151,11 +202,11 @@ class ExternalToolsWindowHelper(object):
         self._merge_id = manager.add_ui_from_string(ui_string)
 
         self.menu = ToolMenu(self._library, self._window,
-                             "/MenuBar/ToolsMenu/ToolsOps_4/ExternalToolPlaceholder")
+                             "/MenuBar/ToolsMenu/ToolsOps_4/ExternalToolsMenu/ExternalToolPlaceholder")
         manager.ensure_update()
 
         # Create output console
-        self._output_buffer = OutputPanel(window)
+        self._output_buffer = OutputPanel(self._plugin.get_data_dir(), window)
         bottom = window.get_bottom_panel()
         bottom.add_item(self._output_buffer.panel,
                         _("Shell Output"),
@@ -175,11 +226,17 @@ class ExternalToolsWindowHelper(object):
         bottom = self._window.get_bottom_panel()
         bottom.remove_item(self._output_buffer.panel)
 
+    def update_manager(self, tool):
+        self._plugin.update_manager(tool)
+
 class ExternalToolsPlugin(gedit.Plugin):
     WINDOW_DATA_KEY = "ExternalToolsPluginWindowData"
 
     def __init__(self):
         super(ExternalToolsPlugin, self).__init__()
+        
+        self._manager = None
+        ToolLibrary().set_locations(os.path.join(self.get_data_dir(), 'tools'))
 
     def activate(self, window):
         helper = ExternalToolsWindowHelper(self, window)
@@ -196,10 +253,22 @@ class ExternalToolsPlugin(gedit.Plugin):
         return self.open_dialog()
 
     def open_dialog(self):
-        tm = Manager().dialog
+        if not self._manager:
+            self._manager = Manager(self.get_data_dir())
+            self._manager.dialog.connect('destroy', self.on_manager_destroy)
+
         window = gedit.app_get_default().get_active_window()
-        if window:
-            tm.set_transient_for(window)
-        return tm
+        self._manager.run(window)
+
+        return self._manager.dialog
+
+    def update_manager(self, tool):
+        if not self._manager:
+            return
+
+        self._manager.tool_changed(tool, True)
+
+    def on_manager_destroy(self, dialog):
+        self._manager = None
 
 # ex:ts=4:et:
