@@ -265,7 +265,7 @@ create_dialog (GeditSpellCheckerDialog *dlg,
 	{
 		gtk_widget_show (error_widget);
 			
-		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dlg)->vbox),
+		gtk_box_pack_start_defaults (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 					     error_widget);
 		
 		return;
